@@ -77,6 +77,9 @@ class CGSmartImage extends CGExtensions
     $this->SetParameterType('notag',CLEAN_INT);
     $this->CreateParameter('notag','',$this->Lang('param_notag'));
 
+    $this->SetParameterType('noremote',CLEAN_INT);
+    $this->CreateParameter('noremote','',$this->Lang('param_noremote'));
+
     $this->SetParameterType('src',CLEAN_STRING);
     $this->CreateParameter('src','',$this->Lang('param_src'),false);
 
@@ -84,6 +87,8 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('overwrite','',$this->Lang('param_overwrite'));
 
     // params for the output tag (if outputting an img tag)
+    $this->SetParameterType('id',CLEAN_STRING);
+    $this->CreateParameter('id','',$this->Lang('param_id'));
 
     $this->SetParameterType('class',CLEAN_STRING);
     $this->CreateParameter('class','',$this->Lang('param_class'));
@@ -110,7 +115,7 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('quality','75',$this->Lang('param_quality'));
 
     $this->SetParameterType('rel',CLEAN_STRING);
-    //$this->CreateParameter('title','',$this->Lang('param_title'));
+    $this->CreateParameter('rel','75',$this->Lang('param_rel'));
 
     $this->CreateParameter('max_width','',$this->Lang('param_max_width'));
     $this->CreateParameter('max_height','',$this->Lang('param_max_height'));
@@ -143,6 +148,7 @@ class CGSmartImage extends CGExtensions
     $smarty->register_block('cgsi_convert',array('cgsi_utils','cgsi_convert'));
   }
 
+
   /*---------------------------------------------------------
    GetName()
    ---------------------------------------------------------*/
@@ -166,7 +172,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.4';
+    return '1.5.1';
   }
 
   
@@ -184,7 +190,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetDependencies()
   {
-    return array('CGExtensions'=>'1.26');
+    return array('CGExtensions'=>'1.26.4');
   }
 
 
