@@ -102,7 +102,7 @@ class CGImage_Resize_Filter extends CGImageFilterBase
     $_dest = new CGImageBase(array($src['type'],$new_w,$new_h));
 
     $res = '';
-    if( $this->resample )
+    if( $this->_resample )
       {
 	$res = imagecopyresampled($_dest['rsrc'],$src['rsrc'],$_dest['rsrc'],0,0,0,0,$new_w,$new_h,$src['width'],$src['height']);
       }
