@@ -125,6 +125,17 @@ class cgsi_utils
   }
 
 
+  private static function _is_stylesheet()
+  {
+    $tmp = debug_backtrace();
+    foreach( $tmp as $elem )
+      {
+	if( isset($elem['function']) && $elem['function'] == 'smarty_cms_function_cms_stylesheet' ) return TRUE;
+      }
+    return FALSE;
+  }
+
+
   public static function &process_image($params)
   {
     $mod = cms_utils::get_module('CGSmartImage');
@@ -141,6 +152,7 @@ class cgsi_utils
     $outp['id'] = '';
     $outp['name'] = '';
     $outp['class'] = '';
+    $outp['style'] = '';
     $outp['src'] = '';
     $outp['width'] = '';
     $outp['height'] = '';
@@ -149,6 +161,7 @@ class cgsi_utils
     $opp = array();  // operation params
     $opp['overwrite'] = 0;
     $opp['nocache'] = 0;
+    $opp['noremote'] = 0;
     $opp['noembed'] = 0;
     $opp['noauto'] = 0;
     $opp['norotate'] = 0;
@@ -203,7 +216,7 @@ class cgsi_utils
       }
     $params = $new_params;
 
-    // second pass, built our arrays
+    // second pass, build our arrays
     foreach( $params as $key => $value )
       {
 	if( startswith($key,'filter_') )
@@ -227,9 +240,12 @@ class cgsi_utils
 	switch( $key )
 	  {
 	  case 'id':
+	  case 'style':
 	  case 'class':
 	  case 'name':
 	  case 'alt':
+	  case 'rel':
+	  case 'title':
 	    $outp[$key] = trim($value);
 	    break;
 	  case 'width':
@@ -248,14 +264,12 @@ class cgsi_utils
 
 	  case 'overwrite':
 	  case 'notag':
+	  case 'noremote':
 	  case 'nocache':
 	  case 'noembed':
 	  case 'norotate':
 	    $opp[$key] = cge_utils::to_bool($value);
 	    break;
-
-	  default:
-	    $outp[$key] = $value;
 	  }
       }
     if( !$outp['error'] && !$opp['src'] )
@@ -293,11 +307,20 @@ class cgsi_utils
 	$tmp = str_replace($config['ssl_url'],$config['root_path'],$opp['src']);
 	if( file_exists($tmp) ) $srcfile = $tmp;
       }
-//     if( !$outp['error'] && !$srcfile && (startswith($opp['src'],'http:') || startswith($opp['src'],'https:') || startswith($opp['src'],'ftp:')) )
-//       {
-// 	// okay, gotta assume that ths is a remote file
-// 	// get it, and cache it.
-//       }
+    if( !$outp['error'] && !$srcfile && $opp['noremote'] == 0 && 
+	(startswith($opp['src'],'http:') || startswith($opp['src'],'https:') || startswith($opp['src'],'ftp:')) )
+       {
+	 // okay, gotta assume that ths is a remote file
+	 // get it, and cache it.
+	 $cachefile = TMP_CACHE_LOCATION.'/cgsi_'.md5($opp['src']).'.img';
+	 if( !file_exists($cachefile) )
+	   {
+	     $data = file_get_contents($opp['src']);
+	     if( !$data ) $opp['error'] = $mod->Lang('error_remotefile',$opp['src']);
+	     if( $data ) file_put_contents($cachefile,$data);
+	   }
+	 $srcfile = $cachefile;
+       }
     if( !$outp['error'] && !$srcfile )
       {
 	$outp['error'] = $mod->Lang('error_srcnotfound',$opp['src']);
@@ -431,7 +454,7 @@ class cgsi_utils
       {
 	// calculate our destination name and url.
 	$tmp = basename($srcfile);
-	$ext = strrchr($srcfile,'.');
+	$ext = strrchr($tmp,'.');
 	$t2 = md5(serialize($opp));
 	$destname = substr($tmp,0,strlen($tmp)-strlen($ext)).'-'.$t2.$ext;
     
@@ -503,12 +526,14 @@ class cgsi_utils
 
     if( !$outp['alt'] )
       {
-	$outp['alt'] = basename($dest_fname);
+	if( $dest_fname ) 
+	  $outp['alt'] = basename($dest_fname);
+	else
+	  $outp['alt'] = basename($srcfile);
       }
 
     // build the output.
-    global $CMS_STYLESHEET;
-    if( $opp['notag'] || isset($CMS_STYLESHEET) )
+    if( $opp['notag'] || self::_is_stylesheet() )
       {
 	$outp['src'] = $dest['url'];
 	if( !$opp['noembed'] && $mod->can_embed($dest_fname) )
@@ -520,6 +545,10 @@ class cgsi_utils
 		$outp['src'] = 'data:'.$type.';base64,'.$tmp;
 	      }
 	  }
+	else
+	  {
+	    $outp['src'] = $dest_url;
+	  }
 
 	if( !isset($outp['output']) )
 	  {
@@ -590,6 +619,7 @@ class cgsi_utils
 	unset($params['max_width']);
       }
 
+    $did_modify = FALSE;
     $mod = cms_utils::get_module('CGSmartImage');
     $old_errorval = libxml_use_internal_errors(true);
     $dom = new CGDomDocument();
@@ -643,6 +673,7 @@ class cgsi_utils
 	      {
 		foreach( $outp as $key => $value )
 		  {
+		    $did_modify = TRUE;
 		    switch( $key )
 		      {
 		      case 'width':
@@ -660,8 +691,24 @@ class cgsi_utils
       }
 
     // get the contents.
-    $tmp = $dom->documentElement->innerHTML;
-    return $tmp;
+    if( $did_modify )
+      {
+	$content = '';
+	$node = $dom->documentElement;
+	$content = $node->innerHTML;
+	$content = str_replace(chr(13),'',$content);
+	if( startswith($content,'<html>') )
+	  {
+	    $content = str_replace('<html>','',$content);
+	    $content = str_replace('</html>','',$content);
+	  }
+	if( startswith($content,'<body>') )
+	  {
+	    $content = str_replace('<body>','',$content);
+	    $content = str_replace('</body>','',$content);
+	  }
+      }
+    return $content;
   }
 }
 
